package com.sooka.sponest.middleware.data.consumer;

import com.alibaba.fastjson.JSON;
import com.ruoyi.common.core.constant.DocumentNameConstants;
import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.log.enums.BusinessType;
import com.sooka.sponest.data.api.basicdata.domain.Firehydrant;
import com.sooka.sponest.data.api.basicdata.domain.Watercrane;
import com.sooka.sponest.data.api.basicdata.domain.Waterintake;
import com.sooka.sponest.data.api.digitalagriculture.domain.*;
import com.sooka.sponest.data.api.digitalemergency.domain.EmergencyEnterprises;
import com.sooka.sponest.data.api.digitalemergency.domain.EmergencyTeam;
import com.sooka.sponest.data.api.digitalemergency.domain.EmergencyWarehouse;
import com.sooka.sponest.data.api.digitalenvironment.domain.EnvironmentKeyEnterprise;
import com.sooka.sponest.data.api.digitalenvironment.domain.EnvironmentSewageOutlet;
import com.sooka.sponest.data.api.digitalenvironment.domain.EnvironmentSourcePollution;
import com.sooka.sponest.data.api.digitalenvironment.domain.EnvironmentWaterMonitor;
import com.sooka.sponest.data.api.digitalfire.domain.*;
import com.sooka.sponest.data.api.digitalforest.domain.Channel;
import com.sooka.sponest.data.api.digitalforest.domain.Fireteam;
import com.sooka.sponest.data.api.digitalforest.domain.KeyFireproofPlots;
import com.sooka.sponest.data.api.digitalforest.domain.Landing;
import com.sooka.sponest.data.api.digitalresource.domain.Deposit;
import com.sooka.sponest.data.api.digitalresource.domain.GeologicHazard;
import com.sooka.sponest.data.api.digitalresource.domain.IllegalConstruction;
import com.sooka.sponest.data.api.digitaltraffic.domain.Bridge;
import com.sooka.sponest.data.api.digitaltraffic.domain.Culvert;
import com.sooka.sponest.data.api.digitaltraffic.domain.WarningSign;
import com.sooka.sponest.data.api.digitalwater.domain.*;
import com.sooka.sponest.middleware.data.basicdata.service.IFirehydrantService;
import com.sooka.sponest.middleware.data.basicdata.service.IWatercraneService;
import com.sooka.sponest.middleware.data.basicdata.service.IWaterintakeService;
import com.sooka.sponest.middleware.data.digitalagriculture.service.*;
import com.sooka.sponest.middleware.data.digitalemergency.service.ICenterdataTEmergencyEnterprisesService;
import com.sooka.sponest.middleware.data.digitalemergency.service.ICenterdataTEmergencyTeamService;
import com.sooka.sponest.middleware.data.digitalemergency.service.ICenterdataTEmergencyWarehouseService;
import com.sooka.sponest.middleware.data.digitalenvironment.dao.CenterdataTEnvironmentKeyEnterpriseDao;
import com.sooka.sponest.middleware.data.digitalenvironment.dao.CenterdataTEnvironmentSewageOutletDao;
import com.sooka.sponest.middleware.data.digitalenvironment.dao.CenterdataTEnvironmentSourcePollutionDao;
import com.sooka.sponest.middleware.data.digitalenvironment.dao.CenterdataTEnvironmentWaterMonitorDao;
import com.sooka.sponest.middleware.data.digitalenvironment.service.ICenterdataTEnvironmentKeyEnterpriseService;
import com.sooka.sponest.middleware.data.digitalenvironment.service.ICenterdataTEnvironmentSewageOutletService;
import com.sooka.sponest.middleware.data.digitalenvironment.service.ICenterdataTEnvironmentSourcePollutionService;
import com.sooka.sponest.middleware.data.digitalenvironment.service.ICenterdataTEnvironmentWaterMonitorService;
import com.sooka.sponest.middleware.data.digitalfirecontrol.service.*;
import com.sooka.sponest.middleware.data.digitalforest.service.IChannelDaoService;
import com.sooka.sponest.middleware.data.digitalforest.service.IFireTeamDaoService;
import com.sooka.sponest.middleware.data.digitalforest.service.IKeyFireproofPlotsDaoService;
import com.sooka.sponest.middleware.data.digitalforest.service.ILandingDaoService;
import com.sooka.sponest.middleware.data.digitalresource.dao.DepositDao;
import com.sooka.sponest.middleware.data.digitalresource.dao.GeologicHazardDao;
import com.sooka.sponest.middleware.data.digitalresource.dao.IllegalConstructionDao;
import com.sooka.sponest.middleware.data.digitalresource.service.IDepositService;
import com.sooka.sponest.middleware.data.digitalresource.service.IGeologicHazardService;
import com.sooka.sponest.middleware.data.digitalresource.service.IIllegalConstructionService;
import com.sooka.sponest.middleware.data.digitaltraffic.dao.BridgeDao;
import com.sooka.sponest.middleware.data.digitaltraffic.dao.CulvertDao;
import com.sooka.sponest.middleware.data.digitaltraffic.dao.WarningSignDao;
import com.sooka.sponest.middleware.data.digitaltraffic.service.IBridgeService;
import com.sooka.sponest.middleware.data.digitaltraffic.service.ICulvertService;
import com.sooka.sponest.middleware.data.digitaltraffic.service.IWarningSignService;
import com.sooka.sponest.middleware.data.digitalwater.dao.*;
import com.sooka.sponest.middleware.data.digitalwater.service.*;
import com.sooka.sponest.middleware.data.visual.entity.bo.DataBO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.stream.annotation.EnableBinding;
import org.springframework.cloud.stream.annotation.StreamListener;
import org.springframework.cloud.stream.messaging.Sink;
import org.springframework.messaging.Message;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

@EnableBinding({Sink.class, DataSink.class}) // （Sink也是spring的）
public class DataListener {

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @StreamListener(DataSink.INPUT1) // 监听
    public void input1(Message<DataBO> message) {
        DataBO dataBO = message.getPayload();
        logger.info("---消费者---{}", dataBO);
        List<String> result = new ArrayList<>();
        if (BusinessType.DELETE.equals(dataBO.getType())) {
            String ids = dataBO.getModelStr().replace("\"", "").replace("[", "").replace("]", "");
            if (ids.contains(",")) {
                result = Arrays.asList(ids.split(","));
            } else {
                result = Collections.singletonList(ids);
            }
        }
        switch (dataBO.getIndexName()) {
            // 基础数据
            case DocumentNameConstants.FOREST_WATERINTAKE:// 取水口
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IWaterintakeService.class).deleteAllById(result);
                } else {
                    Waterintake waterintake = JSON.parseObject(dataBO.getModelStr(), Waterintake.class);
                    SpringUtils.getBean(IWaterintakeService.class).save(waterintake);
                }
                break;
            case DocumentNameConstants.FOREST_WATERCRANE:// 水鹤
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IWatercraneService.class).deleteAllById(result);
                } else {
                    Watercrane watercrane = JSON.parseObject(dataBO.getModelStr(), Watercrane.class);
                    SpringUtils.getBean(IWatercraneService.class).save(watercrane);
                }
                break;
            case DocumentNameConstants.FOREST_FIREHYDRANT1:// 消火栓
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IFirehydrantService.class).deleteAllById(result);
                } else {
                    Firehydrant firehydrant = JSON.parseObject(dataBO.getModelStr(), Firehydrant.class);
                    SpringUtils.getBean(IFirehydrantService.class).save(firehydrant);
                }
                break;
            // 数字林业
            case DocumentNameConstants.FOREST_LANDING:// 起降点
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ILandingDaoService.class).deleteAllById(result);
                } else {
                    Landing landing = JSON.parseObject(dataBO.getModelStr(), Landing.class);
                    SpringUtils.getBean(ILandingDaoService.class).save(landing);
                }
                break;
            case DocumentNameConstants.FOREST_CHANNEL:// 水源渠道信息
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IChannelDaoService.class).deleteAllById(result);
                } else {
                    Channel channel = JSON.parseObject(dataBO.getModelStr(), Channel.class);
                    SpringUtils.getBean(IChannelDaoService.class).save(channel);
                }
                break;
            case DocumentNameConstants.FOREST_FIRETEAM:// 森林防火队
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IFireTeamDaoService.class).deleteAllById(result);
                } else {
                    Fireteam fireteam = JSON.parseObject(dataBO.getModelStr(), Fireteam.class);
                    SpringUtils.getBean(IFireTeamDaoService.class).save(fireteam);
                }
                break;
            case DocumentNameConstants.FOREST_KEY_FIREPROOF_PLOTS:// 重点防火地块管理
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IKeyFireproofPlotsDaoService.class).deleteAllById(result);
                } else {
                    KeyFireproofPlots keyFireproofPlots = JSON.parseObject(dataBO.getModelStr(), KeyFireproofPlots.class);
                    SpringUtils.getBean(IKeyFireproofPlotsDaoService.class).save(keyFireproofPlots);
                }
                break;
            // 数字农业
            case DocumentNameConstants.FARM_AGRICULTURAL_COOPERATIVES:// 农业合作社
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTFarmAgriculturalCooperativesService.class).deleteAllById(result);
                } else {
                    FarmAgriculturalCooperatives centerdataTEnvironmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), FarmAgriculturalCooperatives.class);
                    SpringUtils.getBean(ICenterdataTFarmAgriculturalCooperativesService.class).save(centerdataTEnvironmentSewageOutlet);
                }
                break;
            case DocumentNameConstants.FARM_BOTANY_PROTECT_INFO:// 农业技术推广总站信息
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTFarmBotanyProtectInfoService.class).deleteAllById(result);
                } else {
                    FarmBotanyProtectInfo centerdataTEnvironmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), FarmBotanyProtectInfo.class);
                    SpringUtils.getBean(ICenterdataTFarmBotanyProtectInfoService.class).save(centerdataTEnvironmentSewageOutlet);
                }
                break;
            case DocumentNameConstants.FARM_ENTERPRISE1:// 生鲜乳收购站、屠宰企业、饲料企业
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTFarmEnterpriseService.class).deleteAllById(result);
                } else {
                    FarmEnterprise centerdataTEnvironmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), FarmEnterprise.class);
                    SpringUtils.getBean(ICenterdataTFarmEnterpriseService.class).save(centerdataTEnvironmentSewageOutlet);
                }
                break;
            case DocumentNameConstants.FARM_FILINGS_LIVESTOCK:// 备案畜禽规模养殖场
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTFarmFilingsLivestockService.class).deleteAllById(result);
                } else {
                    FarmFilingsLivestock centerdataTEnvironmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), FarmFilingsLivestock.class);
                    SpringUtils.getBean(ICenterdataTFarmFilingsLivestockService.class).save(centerdataTEnvironmentSewageOutlet);
                }
                break;
            case DocumentNameConstants.FARM_LIVESTOCK:// 种畜禽养殖场
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTFarmLivestockService.class).deleteAllById(result);
                } else {
                    FarmLivestock centerdataTEnvironmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), FarmLivestock.class);
                    SpringUtils.getBean(ICenterdataTFarmLivestockService.class).save(centerdataTEnvironmentSewageOutlet);
                }
                break;
            case DocumentNameConstants.FARM_EXCREMENT_DISPOSE:// 区域性粪污处置中心
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTFarmExcrementDisposeService.class).deleteAllById(result);
                } else {
                    FarmExcrementDispose centerdataTEnvironmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), FarmExcrementDispose.class);
                    SpringUtils.getBean(ICenterdataTFarmExcrementDisposeService.class).save(centerdataTEnvironmentSewageOutlet);
                }
                break;
            case DocumentNameConstants.FARM_COMPLEX_MODIFICATION:// 肉牛基层繁改站
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTFarmComplexModificationService.class).deleteAllById(result);
                } else {
                    FarmComplexModification centerdataTEnvironmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), FarmComplexModification.class);
                    SpringUtils.getBean(ICenterdataTFarmComplexModificationService.class).save(centerdataTEnvironmentSewageOutlet);
                }
                break;
            case DocumentNameConstants.FARM_GREENHOUSE_FILM:// 棚膜信息
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTFarmGreenhouseFilmInfoService.class).deleteAllById(result);
                } else {
                    FarmGreenhouseFilmInfo centerdataTEnvironmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), FarmGreenhouseFilmInfo.class);
                    SpringUtils.getBean(ICenterdataTFarmGreenhouseFilmInfoService.class).save(centerdataTEnvironmentSewageOutlet);
                }
                break;
            // 数字水利
            case DocumentNameConstants.HYDRAULIC_BATTLEFIELD:// 沙场资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicBattlefieldDao.class).deleteAllById(result);
                } else {
                    HydraulicBattlefield hydraulicBattlefield = JSON.parseObject(dataBO.getModelStr(), HydraulicBattlefield.class);
                    SpringUtils.getBean(ICenterdataTHydraulicBattlefieldService.class).save(hydraulicBattlefield);
                }
                break;
            case DocumentNameConstants.HYDRAULIC_CHANNEL_BLUELINE:// 河道蓝线资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicChannelBluelineDao.class).deleteAllById(result);
                } else {
                    HydraulicChannelBluelineApp centerdataTHydraulicChannelBlueline = JSON.parseObject(dataBO.getModelStr(), HydraulicChannelBluelineApp.class);
                    SpringUtils.getBean(ICenterdataTHydraulicChannelBluelineService.class).save(centerdataTHydraulicChannelBlueline);
                }
                break;
            case DocumentNameConstants.HYDRAULIC_GARBAGE_STATION:// 垃圾站资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicGarbageStationDao.class).deleteAllById(result);
                } else {
                    HydraulicGarbageStationApp centerdataTHydraulicGarbageStation = JSON.parseObject(dataBO.getModelStr(), HydraulicGarbageStationApp.class);
                    SpringUtils.getBean(ICenterdataTHydraulicGarbageStationService.class).save(centerdataTHydraulicGarbageStation);
                }
                break;
            case DocumentNameConstants.HYDRAULIC_OUTLET_SEWAGE:// 排污口资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicOutletSewageDao.class).deleteAllById(result);
                } else {
                    HydraulicOutletSewageApp centerdataTHydraulicOutletSewage = JSON.parseObject(dataBO.getModelStr(), HydraulicOutletSewageApp.class);
                    SpringUtils.getBean(ICenterdataTHydraulicOutletSewageService.class).save(centerdataTHydraulicOutletSewage);
                }
                break;
            case DocumentNameConstants.HYDRAULIC_REACH:// 河段资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicReachDao.class).deleteAllById(result);
                } else {
                    HydraulicReachApp hydraulicReachApp = JSON.parseObject(dataBO.getModelStr(), HydraulicReachApp.class);
                    SpringUtils.getBean(ICenterdataTHydraulicReachService.class).save(hydraulicReachApp);
                }
                break;
            case DocumentNameConstants.HYDRAULIC_RESERVOIR:// 水库资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicReservoirDao.class).deleteAllById(result);
                } else {
                    HydraulicReservoirApp hydraulicReservoirApp = JSON.parseObject(dataBO.getModelStr(), HydraulicReservoirApp.class);
                    SpringUtils.getBean(ICenterdataTHydraulicReservoirService.class).save(hydraulicReservoirApp);
                }
                break;
            case DocumentNameConstants.HYDRAULIC_RIVER:// 河流资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicRiverDao.class).deleteAllById(result);
                } else {
                    HydraulicRiverApp hydraulicRiverApp = JSON.parseObject(dataBO.getModelStr(), HydraulicRiverApp.class);
                    SpringUtils.getBean(ICenterdataTHydraulicRiverService.class).save(hydraulicRiverApp);
                }
                break;
            case DocumentNameConstants.HYDRAULIC_WADE_BRIDGE_CULVERT:// 涉水桥涵资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicWadeBridgeCulvertDao.class).deleteAllById(result);
                } else {
                    HydraulicWadeBridgeCulvertApp hydraulicWadeBridgeCulvertApp = JSON.parseObject(dataBO.getModelStr(), HydraulicWadeBridgeCulvertApp.class);
                    SpringUtils.getBean(ICenterdataTHydraulicWadeBridgeCulvertService.class).save(hydraulicWadeBridgeCulvertApp);
                }
                break;
            case DocumentNameConstants.HYDRAULIC_WATER_GATE:// 闸口资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTHydraulicWaterGateDao.class).deleteAllById(result);
                } else {
                    HydraulicWaterGateApp hydraulicWaterGateApp = JSON.parseObject(dataBO.getModelStr(), HydraulicWaterGateApp.class);
                    SpringUtils.getBean(ICenterdataTHydraulicWaterGateService.class).save(hydraulicWaterGateApp);
                }
                break;
            // 数字环保
            case DocumentNameConstants.ENVIRONMENT_KEY_ENTERPRISE:// 重点企业管理
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTEnvironmentKeyEnterpriseDao.class).deleteAllById(result);
                } else {
                    EnvironmentKeyEnterprise environmentKeyEnterprise = JSON.parseObject(dataBO.getModelStr(), EnvironmentKeyEnterprise.class);
                    SpringUtils.getBean(ICenterdataTEnvironmentKeyEnterpriseService.class).save(environmentKeyEnterprise);
                }
                break;
            case DocumentNameConstants.ENVIRONMENT_SOURCE_POLLUTION:// 污染源管理
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTEnvironmentSourcePollutionDao.class).deleteAllById(result);
                } else {
                    EnvironmentSourcePollution environmentSourcePollution = JSON.parseObject(dataBO.getModelStr(), EnvironmentSourcePollution.class);
                    SpringUtils.getBean(ICenterdataTEnvironmentSourcePollutionService.class).save(environmentSourcePollution);
                }
                break;
            case DocumentNameConstants.ENVIRONMENT_SEWAGE_OUTLET:// 排污口
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTEnvironmentSewageOutletDao.class).deleteAllById(result);
                } else {
                    EnvironmentSewageOutlet environmentSewageOutlet = JSON.parseObject(dataBO.getModelStr(), EnvironmentSewageOutlet.class);
                    SpringUtils.getBean(ICenterdataTEnvironmentSewageOutletService.class).save(environmentSewageOutlet);
                }
                break;
            case DocumentNameConstants.ENVIRONMENT_WATER_MONITOR:// 水质断面监测
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CenterdataTEnvironmentWaterMonitorDao.class).deleteAllById(result);
                } else {
                    EnvironmentWaterMonitor environmentWaterMonitor = JSON.parseObject(dataBO.getModelStr(), EnvironmentWaterMonitor.class);
                    SpringUtils.getBean(ICenterdataTEnvironmentWaterMonitorService.class).save(environmentWaterMonitor);
                }
                break;
            // 数字应急
            case DocumentNameConstants.EMERGENCY_WAREHOUSE:// 应急仓库
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTEmergencyWarehouseService.class).deleteAllById(result);
                } else {
                    EmergencyWarehouse emergencyWarehouse = JSON.parseObject(dataBO.getModelStr(), EmergencyWarehouse.class);
                    SpringUtils.getBean(ICenterdataTEmergencyWarehouseService.class).save(emergencyWarehouse);
                }
                break;
            case DocumentNameConstants.EMERGENCY_TEAM:// 应急队伍
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTEmergencyTeamService.class).deleteAllById(result);
                } else {
                    EmergencyTeam emergencyTeam = JSON.parseObject(dataBO.getModelStr(), EmergencyTeam.class);
                    SpringUtils.getBean(ICenterdataTEmergencyTeamService.class).save(emergencyTeam);
                }
                break;
            case DocumentNameConstants.EMERGENCY_IDLH_ENTERPRISES:// 危化企业
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(ICenterdataTEmergencyEnterprisesService.class).deleteAllById(result);
                } else {
                    EmergencyEnterprises emergencyEnterprises = JSON.parseObject(dataBO.getModelStr(), EmergencyEnterprises.class);
                    SpringUtils.getBean(ICenterdataTEmergencyEnterprisesService.class).save(emergencyEnterprises);
                }
                break;
            // 数字交通
            case DocumentNameConstants.TRAFFIC_WARNING_SIGN:// 警示牌资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(WarningSignDao.class).deleteAllById(result);
                } else {
                    WarningSign warningSign = JSON.parseObject(dataBO.getModelStr(), WarningSign.class);
                    SpringUtils.getBean(IWarningSignService.class).save(warningSign);
                }
                break;
            case DocumentNameConstants.TRAFFIC_BRIDGE:// 桥梁资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(BridgeDao.class).deleteAllById(result);
                } else {
                    Bridge bridge = JSON.parseObject(dataBO.getModelStr(), Bridge.class);
                    SpringUtils.getBean(IBridgeService.class).save(bridge);
                }
                break;
            case DocumentNameConstants.TRAFFIC_CULVERT:// 涵洞资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(CulvertDao.class).deleteAllById(result);
                } else {
                    Culvert culvert = JSON.parseObject(dataBO.getModelStr(), Culvert.class);
                    SpringUtils.getBean(ICulvertService.class).save(culvert);
                }
                break;
            // 数字资源
            case DocumentNameConstants.RESOURCES_DEPOSIT:// 矿产资源
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(DepositDao.class).deleteAllById(result);
                } else {
                    Deposit deposit = JSON.parseObject(dataBO.getModelStr(), Deposit.class);
                    SpringUtils.getBean(IDepositService.class).save(deposit);
                }
                break;
            case DocumentNameConstants.RESOURCES_GEOLOGIC_HAZARD:// 地质灾害易发区
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(GeologicHazardDao.class).deleteAllById(result);
                } else {
                    GeologicHazard geologicHazard = JSON.parseObject(dataBO.getModelStr(), GeologicHazard.class);
                    SpringUtils.getBean(IGeologicHazardService.class).save(geologicHazard);
                }
                break;
            case DocumentNameConstants.RESOURCES_ILLEGAL_CONSTRUCTION:// 违建信息
                if (BusinessType.DELETE.equals(dataBO.getType())) {
                    SpringUtils.getBean(IllegalConstructionDao.class).deleteAllById(result);
                } else {
                    IllegalConstruction illegalConstruction = JSON.parseObject(dataBO.getModelStr(), IllegalConstruction.class);
                    SpringUtils.getBean(IIllegalConstructionService.class).save(illegalConstruction);
                }
                break;
            // 数字消防
            case DocumentNameConstants.FIRECONTROL_FIRE_FORCE:// 消防力量管理
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IFireForceService.class).deleteAllById(result);
                } else {
                    FireForce fireForce = JSON.parseObject(dataBO.getModelStr(), FireForce.class);
                    SpringUtils.getBean(IFireForceService.class).save(fireForce);
                }
                break;
            case DocumentNameConstants.FIRECONTROL_FIRE_KEY_PLACES:// 重点场所管理
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IFireKeyPlacesService.class).deleteAllById(result);
                } else {
                    FireKeyPlaces fireKeyPlaces = JSON.parseObject(dataBO.getModelStr(), FireKeyPlaces.class);
                    SpringUtils.getBean(IFireKeyPlacesService.class).save(fireKeyPlaces);
                }
                break;
            case DocumentNameConstants.FIRECONTROL_FIRE_PRESSURE_SENSOR:// 压力传感器管理
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IFirePressureSensorService.class).deleteAllById(result);
                } else {
                    FirePressureSensor firePressureSensor = JSON.parseObject(dataBO.getModelStr(), FirePressureSensor.class);
                    SpringUtils.getBean(IFirePressureSensorService.class).save(firePressureSensor);
                }
                break;
            case DocumentNameConstants.FIRECONTROL_BASIC_LINKAGE_FORCE:// 基本联动力量管理
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IBasicLinkageForceService.class).deleteAllById(result);
                } else {
                    BasicLinkageForce basicLinkageForce = JSON.parseObject(dataBO.getModelStr(), BasicLinkageForce.class);
                    SpringUtils.getBean(IBasicLinkageForceService.class).save(basicLinkageForce);
                }
                break;
            case DocumentNameConstants.FIRECONTROL_OTHER_LINKAGE_FORCE:// 其他联动力量管理
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IFireOtherLinkageForceService.class).deleteAllById(result);
                } else {
                    FireOtherLinkageForce fireOtherLinkageForce = JSON.parseObject(dataBO.getModelStr(), FireOtherLinkageForce.class);
                    SpringUtils.getBean(IFireOtherLinkageForceService.class).save(fireOtherLinkageForce);
                }
                break;
            case DocumentNameConstants.FIRECONTROL_FOAM_LIQUID:// 泡沫液管理
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IFireFoamLiquidService.class).deleteAllById(result);
                } else {
                    FireFoamLiquid fireteam = JSON.parseObject(dataBO.getModelStr(), FireFoamLiquid.class);
                    SpringUtils.getBean(IFireFoamLiquidService.class).save(fireteam);
                }
                break;
            case DocumentNameConstants.FIRECONTROL_FULLTIME_STATION:// 专职站管理
                if (dataBO.getType().equals(BusinessType.DELETE)) {
                    SpringUtils.getBean(IFireFultimeStationService.class).deleteAllById(result);
                } else {
                    FireFulltimeStation fireFulltimeStation = JSON.parseObject(dataBO.getModelStr(), FireFulltimeStation.class);
                    SpringUtils.getBean(IFireFultimeStationService.class).save(fireFulltimeStation);
                }
                break;
            default:
                logger.info("无效索引---{}", dataBO.getIndexName());
                break;
        }
    }
}
